@@ -5,6 +5,8 @@ import dash_bootstrap_components as dbc
 import dash_html_components as html
 from dash import Dash
 
+from rubicon_ml import Rubicon
+from rubicon_ml.exceptions import RubiconException
 from rubicon_ml.ui.callbacks import (
     set_project_explorer_callbacks,
     set_project_selection_callbacks,
@@ -19,11 +21,20 @@ from rubicon_ml.ui.views import (
 
 
 class Dashboard:
-    """The dashboard for exploring logged data.
+    """A dashboard for exploring logged data. The dashboard
+    relies on existing rubicon_ml data, which can be passed
+    in the following ways:
+        * by passing in an existing Rubicon object, which can be the
+          the synchronous or asynchronous version (see param details below).
+        * by passing in ``persistence`` and ``root_dir``, which will configure
+          a rubicon object for you (useful from CLI or independent dashboard configuration).
 
     Parameters
     ----------
-    persistence : str
+    rubicon : rubicon_ml.Rubicon or rubicon_ml.client.asynchronous.Rubicon, optional
+        A top level Rubicon instance which holds the configuration for
+        the data you wish to visualize.
+    persistence : str, optional
         The persistence type. Can be one of ["filesystem", "memory"].
     root_dir : str, optional
         Absolute or relative filepath of the root directory holding Rubicon data.
@@ -39,18 +50,29 @@ class Dashboard:
         troubles.
     storage_options : dict, optional
         Additional keyword arguments specific to the protocol being chosen. They
-        are passed directly to the underlying filesystem class.
+        are passed directly to the underlying filesystem class when ``persistence``
+        and ``root_dir`` are used.
     """
 
     def __init__(
         self,
-        persistence,
+        rubicon=None,
+        persistence=None,
         root_dir=None,
         page_size=10,
         dash_options={},
         **storage_options,
     ):
-        self.rubicon_model = RubiconModel(persistence, root_dir, **storage_options)
+
+        if not rubicon and not all([persistence, root_dir]):
+            raise RubiconException(
+                "Either `rubicon` or both `persistence` and `root_dir` must be provided."
+            )
+
+        if not rubicon:
+            rubicon = Rubicon(persistence, root_dir, **storage_options)
+
+        self.rubicon_model = RubiconModel(rubicon)
 
         self._app = Dash(__name__, title="Rubicon", **dash_options)
         self._app._rubicon_model = self.rubicon_model
